Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Migration Hub Refactor Spaces.

Actions, resources, and condition keys for AWS Migration Hub Refactor Spaces - Service Authorization Reference

# Actions, resources, and condition keys for AWS Migration Hub Refactor Spaces

AWS Migration Hub Refactor Spaces (service prefix: `refactor-spaces` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Migration Hub Refactor Spaces
- Resource types defined by AWS Migration Hub Refactor Spaces
- Condition keys for AWS Migration Hub Refactor Spaces

## Actions defined by AWS Migration Hub Refactor Spaces

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateApplication | Grants permission to create an application within an environment | Write |  | refactor-spaces:ApplicationCreatedByAccount refactor-spaces:CreatedByAccountIds aws:RequestTag/${TagKey} aws:TagKeys |
CreateEnvironment | Grants permission to create an environment | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateRoute | Grants permission to create a route within an application | Write |  | refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:RouteCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:SourcePath aws:RequestTag/${TagKey} aws:TagKeys |
CreateService | Grants permission to create a service within an application | Write |  | refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:CreatedByAccountIds aws:RequestTag/${TagKey} aws:TagKeys |
DeleteApplication | Grants permission to delete an application from an environment | Write | application* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:CreatedByAccountIds aws:ResourceTag/${TagKey} |
DeleteEnvironment | Grants permission to delete an environment | Write | environment* |  |
| aws:ResourceTag/${TagKey} |
DeleteResourcePolicy | Grants permission to delete a resource policy | Write |  |  |
DeleteRoute | Grants permission to delete a route from an application | Write | route* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:RouteCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:SourcePath aws:ResourceTag/${TagKey} |
DeleteService | Grants permission to delete a service from an application | Write | service* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:CreatedByAccountIds aws:ResourceTag/${TagKey} |
GetApplication | Grants permission to get more information about an application | Read | application* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:CreatedByAccountIds aws:ResourceTag/${TagKey} |
GetEnvironment | Grants permission to get more information for an environment | Read | environment* |  |
| aws:ResourceTag/${TagKey} |
GetResourcePolicy | Grants permission to get the details about a resource policy | Read |  |  |
GetRoute | Grants permission to get more information about a route | Read | route* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:RouteCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:SourcePath aws:ResourceTag/${TagKey} |
GetService | Grants permission to get more information about a service | Read | service* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:CreatedByAccountIds aws:ResourceTag/${TagKey} |
ListApplications | Grants permission to list all the applications in an environment | Read | application* |  |
ListEnvironmentVpcs | Grants permission to list all the VPCs for the environment | Read | environment* |  |
ListEnvironments | Grants permission to list all environments | Read |  |  |
ListRoutes | Grants permission to list all the routes in an application | Read | route* |  |
ListServices | Grants permission to list all the services in an environment | Read | environment* |  |
ListTagsForResource | Grants permission to list all the tags for a given resource | Read |  |  |
PutResourcePolicy | Grants permission to add a resource policy | Write |  |  |
TagResource | Grants permission to tag a resource | Tagging | application |  |
environment |  |
route |  |
service |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:RouteCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:SourcePath aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove a tag from a resource | Tagging | application |  |
environment |  |
route |  |
service |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:RouteCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:SourcePath aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UpdateRoute | Grants permission to update a route from an application | Write | route* |  |
| refactor-spaces:ApplicationCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:RouteCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:SourcePath aws:ResourceTag/${TagKey} |

## Resource types defined by AWS Migration Hub Refactor Spaces

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
environment | `arn:$ { Partition}:refactor-spaces:$ { Region}:$ { Account}:environment/$ { EnvironmentId}` | aws:ResourceTag/${TagKey}
application | `arn:$ { Partition}:refactor-spaces:$ { Region}:$ { Account}:environment/$ { EnvironmentId}/application/$ { ApplicationId}` | aws:ResourceTag/${TagKey} refactor-spaces:ApplicationCreatedByAccount refactor-spaces:CreatedByAccountIds
service | `arn:$ { Partition}:refactor-spaces:$ { Region}:$ { Account}:environment/$ { EnvironmentId}/application/$ { ApplicationId}/service/$ { ServiceId}` | aws:ResourceTag/${TagKey} refactor-spaces:ApplicationCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:ServiceCreatedByAccount
route | `arn:$ { Partition}:refactor-spaces:$ { Region}:$ { Account}:environment/$ { EnvironmentId}/application/$ { ApplicationId}/route/$ { RouteId}` | aws:ResourceTag/${TagKey} refactor-spaces:ApplicationCreatedByAccount refactor-spaces:CreatedByAccountIds refactor-spaces:RouteCreatedByAccount refactor-spaces:ServiceCreatedByAccount refactor-spaces:SourcePath

## Condition keys for AWS Migration Hub Refactor Spaces

AWS Migration Hub Refactor Spaces defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString
refactor-spaces:ApplicationCreatedByAccount | Filters access by restricting the action to only those accounts that created the application within an environment | String
refactor-spaces:CreatedByAccountIds | Filters access by the accounts that created the resource | ArrayOfString
refactor-spaces:RouteCreatedByAccount | Filters access by restricting the action to only those accounts that created the route within an application | String
refactor-spaces:ServiceCreatedByAccount | Filters access by restricting the action to only those accounts that created the service within an application | String
refactor-spaces:SourcePath | Filters access by the path of the route | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.